#
# Spec file for Qpid C++ packages: qpid-cpp-server*, qpid-cpp-client*
# svn revision: $Rev$
#

%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?ruby_sitelib: %global ruby_sitelib %(/usr/bin/ruby -rrbconfig  -e 'puts Config::CONFIG["sitelibdir"] ')}
%{!?ruby_sitearch: %global ruby_sitearch %(/usr/bin/ruby -rrbconfig -e 'puts Config::CONFIG["sitearchdir"] ')}

# ===========

%global base_name qpid-cpp

# Version numbers
%global store_version       0.18
%global store_svnrev        4509

# NOTE: no more than one of these flags should be set at the same time!
# RHEL-6 builds (the default) should have both these flags set to 0.
%global fedora              0
%global rhel_5              1

# LIBRARY VERSIONS
# Update these lib numbers in accordance with library numbering policy and best practices.
# http://www.gnu.org/software/libtool/manual/libtool.html#Versioning
#
# Fromat: current[:revision[:age]]
#
# current:  The most recent interface number that this library implements.
# revision: The implementation number of the current interface.
# age:      The difference between the newest and oldest interfaces that this library implements.
#           In other words, the library implements all the interface numbers in the range from
#           number current - age to current. 
#
#  1. Start with version information of ‘0:0:0’ for each libtool library.
#  2. Update the version information only immediately before a public release of your software.
#     More frequent updates are unnecessary, and only guarantee that the current interface number
#     gets larger faster.
#  3. If the library source code has changed at all since the last update, then increment revision
#     (‘c:r:a’ becomes ‘c:r+1:a’).
#  4. If any interfaces have been added, removed, or changed since the last update, increment current,
#     and set revision to 0.
#  5. If any interfaces have been added since the last public release, then increment age.
#  6. If any interfaces have been removed or changed since the last public release, then set age to 0. 

%global QPIDCOMMON_VERSION_INFO             8:0:0
%global QPIDTYPES_VERSION_INFO              3:2:2
%global QPIDBROKER_VERSION_INFO             8:0:0
%global QPIDCLIENT_VERSION_INFO             8:0:0
%global QPIDMESSAGING_VERSION_INFO          5:2:2
%global RDMAWRAP_VERSION_INFO               8:0:0
%global SSLCOMMON_VERSION_INFO              8:0:0

# Note that qpidtypes and qpidmessaging are the libraries which contain
# our official public interfaces and we try not to change.
# The others have no guarantee, which is why we rev them with every release.
# ===========

# Single var with all lib version params (except store) for make
%global LIB_VERSION_MAKE_PARAMS QPIDCOMMON_VERSION_INFO=%{QPIDCOMMON_VERSION_INFO} QPIDTYPES_VERSION_INFO=%{QPIDTYPES_VERSION_INFO} QPIDBROKER_VERSION_INFO=%{QPIDBROKER_VERSION_INFO} QPIDCLIENT_VERSION_INFO=%{QPIDCLIENT_VERSION_INFO} QPIDMESSAGING_VERSION_INFO=%{QPIDMESSAGING_VERSION_INFO} RDMAWRAP_VERSION_INFO=%{RDMAWRAP_VERSION_INFO} SSLCOMMON_VERSION_INFO=%{SSLCOMMON_VERSION_INFO}

# ===========

# Disable RDMA on s390(x) and ppc(64) architectures
%ifarch s390 s390x ppc ppc64
%global with_rdma 0
%else
%global with_rdma 1
%endif

# Disable cluster (cpg option) and xml on s390* and ppc* architectures
%ifarch s390 s390x ppc ppc64
%global with_cluster 0
%global with_xml 0
%else
%global with_cluster 1
%global with_xml 1
%endif

Name:           qpid-cpp-mrg
Version:        0.18
Release:        39%{?dist}
Summary:        Libraries for Qpid C++ client applications
Group:          System Environment/Libraries
License:        ASL 2.0
URL:            http://qpid.apache.org
Source0:        qpid-%{version}.tar.gz
Source1:        store-%{store_version}.tar.gz
Source2:        qpid-cpp-doxygen-%{version}.html.tar.gz
Source3:        qpidd.pp
Source4:        qpidd.1.gz
Source5:        qpidd.sasldb
Patch0:         mrg.patch
Patch2:         store-0.18.patch
Patch3:         mrg-2.3.3.patch
Patch4:         mrg-2.3.6.patch
Patch5:         store-2.3.6.patch
Patch6:         mrg-2.4.4.patch
Patch7:         configure.patch
Patch8:         mrg-2.5.1.patch
Patch9:         mrg-2.5.5.patch
Patch10:        mrg-2.5.9.patch
Patch11:        mrg-2.5.13.patch
Patch12:        mrg-2.5.17.patch
%if %{fedora}
Patch1:         so_number.patch
%endif
BuildRoot:      %{_tmppath}/%{base_name}-%{version}-%{release}-root-%(%{__id_u} -n)
%if %{rhel_5}
ExclusiveArch:  i386 x86_64
%endif

BuildRequires: boost-devel
BuildRequires: libtool
BuildRequires: pkgconfig
BuildRequires: ruby
BuildRequires: ruby-devel
BuildRequires: python
BuildRequires: python-devel
BuildRequires: swig
BuildRequires: cyrus-sasl-devel
BuildRequires: cyrus-sasl-lib
BuildRequires: cyrus-sasl
%if %{rhel_5}
BuildRequires: e2fsprogs-devel
%else
BuildRequires: boost-program-options
BuildRequires: boost-filesystem
BuildRequires: libuuid-devel
%endif

%if %{with_rdma}
BuildRequires: libibverbs-devel
BuildRequires: librdmacm-devel
%endif

BuildRequires: nss-devel
BuildRequires: nspr-devel

%if %{with_xml}
BuildRequires: xqilla-devel
BuildRequires: xerces-c-devel
%endif

BuildRequires: db4-devel
BuildRequires: libaio-devel
%if %{rhel_5}
BuildRequires: openais-devel
BuildRequires: cman-devel
%else
%if %{with_cluster}
BuildRequires: corosynclib-devel
BuildRequires: clusterlib-devel
%endif
%endif


%description

Run-time libraries for AMQP client applications developed using Qpid
C++. Clients exchange messages with an AMQP message broker using
the AMQP protocol.

# === Package: qpid-cpp-client ===

%package -n %{base_name}-client
Summary: Libraries for Qpid C++ client applications
Group: System Environment/Libraries
Requires: boost
Obsoletes: qpidc

Requires(post):/sbin/chkconfig
Requires(preun):/sbin/chkconfig
Requires(preun):/sbin/service
Requires(postun):/sbin/service

%description -n %{base_name}-client
Run-time libraries for AMQP client applications developed using Qpid
C++. Clients exchange messages with an AMQP message broker using
the AMQP protocol.

%files -n %{base_name}-client
%defattr(-,root,root,-)
%doc cpp/LICENSE
%doc cpp/NOTICE
%doc cpp/README.txt
%doc cpp/INSTALL
%doc cpp/RELEASE_NOTES
%doc cpp/DESIGN
%_libdir/libqpidcommon.so.*
%_libdir/libqpidclient.so.*
%_libdir/libqpidmessaging.so.*
%_libdir/libqpidtypes.so.*
%dir %_libdir/qpid
%dir %_libdir/qpid/client
%dir %_sysconfdir/qpid
%config(noreplace) %_sysconfdir/qpid/qpidc.conf

%post -n %{base_name}-client
/sbin/ldconfig

%postun -n %{base_name}-client
/sbin/ldconfig

# === Package: qpid-cpp-client-devel ===

%package -n %{base_name}-client-devel
Summary: Header files, documentation and testing tools for developing Qpid C++ clients
Group: Development/System
Requires: %{base_name}-client = %{version}-%{release}
Requires: boost-devel
Requires: %_includedir/uuid/uuid.h
%if ! %{rhel_5}
Requires: boost-filesystem
Requires: boost-program-options
%endif
Requires: python
Obsoletes: qpidc-devel
Obsoletes: qpidc-perftest

%description -n %{base_name}-client-devel
Libraries, header files and documentation for developing AMQP clients
in C++ using Qpid.  Qpid implements the AMQP messaging specification.

%files -n %{base_name}-client-devel
%defattr(-,root,root,-)
%dir %_includedir/qpid
%_includedir/qpid/*.h
%_includedir/qpid.i
%_includedir/swig_perl_typemaps.i
%_includedir/qpid/amqp_0_10
%_includedir/qpid/client
%_includedir/qpid/framing
%_includedir/qpid/sys
%_includedir/qpid/log
%_includedir/qpid/management
%_includedir/qpid/messaging
%_includedir/qpid/types
%_libdir/libqpidcommon.so
%_libdir/libqpidclient.so
%_libdir/libqpidmessaging.so
%_libdir/libqpidtypes.so
%_libdir/pkgconfig/qpid.pc
%_datadir/qpidc/examples/messaging
%defattr(755,root,root,-)
%_bindir/qpid-perftest
%_bindir/qpid-topic-listener
%_bindir/qpid-topic-publisher
%_bindir/qpid-latency-test
%_bindir/qpid-client-test
%_bindir/qpid-txtest

%post -n %{base_name}-client-devel
/sbin/ldconfig

%postun -n %{base_name}-client-devel
/sbin/ldconfig

# === Package: qpid-cpp-client-devel-docs ===

%package -n %{base_name}-client-devel-docs
Summary: AMQP client development documentation
Group: Documentation
%if !%{rhel_5}
BuildArch: noarch
%endif
Obsoletes: qpidc-devel-docs

%description -n %{base_name}-client-devel-docs
This package includes the AMQP clients development documentation in HTML
format for easy browsing.

%files -n %{base_name}-client-devel-docs
%defattr(-,root,root,-)
%doc html

# === Package: qpid-cpp-server ===

%package -n %{base_name}-server
Summary: An AMQP message broker daemon
Group: System Environment/Daemons
Requires: %{base_name}-client = %{version}-%{release}
Requires: cyrus-sasl
%if %{rhel_5}
Requires(pre): selinux-policy-base
Requires(post): /usr/sbin/semodule
Requires(postun): /usr/sbin/semodule
%endif
Obsoletes: qpidd
Obsoletes: qpidd-acl

%description -n %{base_name}-server
A message broker daemon that receives stores and routes messages using
the open AMQP messaging protocol.

%files -n %{base_name}-server
%defattr(-,root,root,-)
%_libdir/libqpidbroker.so.*
%_libdir/qpid/daemon/replicating_listener.so
%_libdir/qpid/daemon/replication_exchange.so
%_sbindir/qpidd
%config(noreplace) %_sysconfdir/qpidd.conf
%config(noreplace) %_sysconfdir/sasl2/qpidd.conf
%config(noreplace) %_sysconfdir/qpid/qpidd.acl
%{_initrddir}/qpidd
%dir %_libdir/qpid/daemon
%_libdir/qpid/daemon/acl.so
%attr(755, qpidd, qpidd) %dir %_localstatedir/lib/qpidd
%attr(600, qpidd, qpidd) %config(noreplace) %_localstatedir/lib/qpidd/qpidd.sasldb
%attr(755, qpidd, qpidd) %dir %_localstatedir/run/qpidd
%doc %_mandir/man1/qpidd.*
%if %{rhel_5}
%_datadir/selinux/packages/qpidd.pp
%endif

%pre -n %{base_name}-server
getent group qpidd >/dev/null || groupadd -r qpidd
getent passwd qpidd >/dev/null || \
  useradd -r -M -g qpidd -d %{_localstatedir}/lib/qpidd -s /sbin/nologin \
    -c "Owner of Qpidd Daemons" qpidd
exit 0

%post -n %{base_name}-server
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add qpidd
/sbin/ldconfig
%if %{rhel_5}
/usr/sbin/semodule -i %{_datadir}/selinux/packages/qpidd.pp
%endif

%preun -n %{base_name}-server
# Check that this is actual deinstallation, not just removing for upgrade.
if [ "$1" = "0" ]; then
        /sbin/service qpidd stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del qpidd
fi

%postun -n %{base_name}-server
if [ "$1" -ge "1" ]; then
        /sbin/service qpidd condrestart >/dev/null 2>&1 || :
fi
/sbin/ldconfig
%if %{rhel_5}
if [ "$1" = "0" ]; then
   /usr/sbin/semodule -r qpidd
fi
%endif

# === Package: qpid-cpp-server-devel ===

%package -n %{base_name}-server-devel
Summary: Libraries and header files for developing Qpid broker extensions
Group: Development/System
Requires: %{base_name}-client-devel = %{version}-%{release}
Requires: %{base_name}-server = %{version}-%{release}
Requires: boost-devel
%if !%{rhel_5}
Requires: boost-filesystem
Requires: boost-program-options
%endif
Obsoletes: qpidd-devel

%description -n %{base_name}-server-devel
Libraries and header files for developing extensions to the
Qpid broker daemon.

%files -n %{base_name}-server-devel
%defattr(-,root,root,-)
%_libdir/libqpidbroker.so
%_includedir/qpid/broker

%post -n %{base_name}-server-devel
/sbin/ldconfig

%postun -n %{base_name}-server-devel
/sbin/ldconfig

# === Package: qpid-cpp-server-ha ===

%package -n %{base_name}-server-ha
Summary: Provides extensions to the AMQP message broker to provide high availability
Group: System Environment/Daemons

Requires: %{base_name}-server = %{version}-%{release}

%description -n %{base_name}-server-ha
%{summary}.

%files -n %{base_name}-server-ha
%{_bindir}/qpid-ha
%{_initrddir}/qpidd-primary
%{_libdir}/qpid/daemon/ha.so

%post -n %{base_name}-server-ha
/sbin/chkconfig --add qpidd-primary
/sbin/ldconfig

%preun -n %{base_name}-server-ha
if [ $1 = 0 ]; then
  /sbin/service qpidd-primary stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del qpidd-primary
fi

%postun -n %{base_name}-server-ha
if [ $1 -ge 1 ]; then
  /sbin/service qpidd-primary condrestart >/dev/null 2>&1 || :
fi
/sbin/ldconfig



%if %{with_rdma}
# === Package: qpid-cpp-client-rdma ===

%package -n %{base_name}-client-rdma
Summary: RDMA Protocol support (including Infiniband) for Qpid clients
Group: System Environment/Libraries
Requires: %{base_name}-client = %{version}-%{release}
Obsoletes: qpidc-rdma

%description -n %{base_name}-client-rdma
A client plugin and support library to support RDMA protocols (including
Infiniband) as the transport for Qpid messaging.

%files -n %{base_name}-client-rdma
%defattr(-,root,root,-)
%_libdir/librdmawrap.so.*
%_libdir/qpid/client/rdmaconnector.so
%config(noreplace) %_sysconfdir/qpid/qpidc.conf

%post -n %{base_name}-client-rdma
/sbin/ldconfig

%postun -n %{base_name}-client-rdma
/sbin/ldconfig

# === Package: qpid-cpp-server-rdma ===

%package -n %{base_name}-server-rdma
Summary: RDMA Protocol support (including Infiniband) for the Qpid daemon
Group: System Environment/Libraries
Requires: %{base_name}-server = %{version}-%{release}
Requires: %{base_name}-client-rdma = %{version}-%{release}
Obsoletes: qpidd-rdma

%description -n %{base_name}-server-rdma
A Qpid daemon plugin to support RDMA protocols (including Infiniband) as the
transport for AMQP messaging.

%files -n %{base_name}-server-rdma
%defattr(-,root,root,-)
%_libdir/qpid/daemon/rdma.so

%post -n %{base_name}-server-rdma
/sbin/ldconfig

%postun -n %{base_name}-server-rdma
/sbin/ldconfig

%endif # with_rdma

# === Package: qpid-cpp-client-ssl ===

%package -n %{base_name}-client-ssl
Summary: SSL support for Qpid clients
Group: System Environment/Libraries
Requires: %{base_name}-client = %{version}-%{release}
Obsoletes: qpidc-ssl

%description -n %{base_name}-client-ssl
A client plugin and support library to support SSL as the transport
for Qpid messaging.

%files -n %{base_name}-client-ssl
%defattr(-,root,root,-)
%_libdir/libsslcommon.so.*
%_libdir/qpid/client/sslconnector.so

%post -n %{base_name}-client-ssl
/sbin/ldconfig

%postun -n %{base_name}-client-ssl
/sbin/ldconfig

# === Package: qpid-cpp-server-ssl ===

%package -n %{base_name}-server-ssl
Summary: SSL support for the Qpid daemon
Group: System Environment/Libraries
Requires: %{base_name}-server = %{version}-%{release}
Requires: %{base_name}-client-ssl = %{version}-%{release}
Obsoletes: qpidd-ssl

%description -n %{base_name}-server-ssl
A Qpid daemon plugin to support SSL as the transport for AMQP
messaging.

%files -n %{base_name}-server-ssl
%defattr(-,root,root,-)
%_libdir/qpid/daemon/ssl.so

%post -n %{base_name}-server-ssl
/sbin/ldconfig

%postun -n %{base_name}-server-ssl
/sbin/ldconfig

%if %{with_xml}
# === Package: qpid-cpp-server-xml ===

%package -n %{base_name}-server-xml
Summary: XML extensions for the Qpid daemon
Group: System Environment/Libraries
Requires: %{base_name}-server = %{version}-%{release}
Requires: %{base_name}-client = %{version}-%{release}
Requires: xqilla
Requires: xerces-c
Obsoletes: qpidd-xml

%description -n %{base_name}-server-xml
A Qpid daemon plugin to support extended XML-based routing of AMQP
messages.

%files -n %{base_name}-server-xml
%defattr(-,root,root,-)
%_libdir/qpid/daemon/xml.so

%post -n %{base_name}-server-xml
/sbin/ldconfig

%postun -n %{base_name}-server-xml
/sbin/ldconfig
%endif

%if %{with_cluster}
# === Package: qpid-cpp-server-cluster ===

%package -n %{base_name}-server-cluster
Summary: Cluster support for the Qpid daemon
Group: System Environment/Daemons
Requires: %{base_name}-server = %{version}-%{release}
Requires: %{base_name}-client = %{version}-%{release}
%if %{rhel_5}
Requires: openais
Requires: cman
%else
Requires: corosync
Requires: clusterlib
%endif
Obsoletes: qpidd-cluster

%description -n %{base_name}-server-cluster
%if %{rhel_5}
A Qpid daemon plugin enabling broker clustering using openais.
%else
A Qpid daemon plugin enabling broker clustering using corosync.
%endif

%files -n %{base_name}-server-cluster
%defattr(-,root,root,-)
%_libdir/qpid/daemon/cluster.so
%_libdir/qpid/daemon/watchdog.so
%_libexecdir/qpid/qpidd_watchdog

%post -n %{base_name}-server-cluster
%if %{rhel_5}
# [RHEL-5] openais: Make the qpidd user a member of the root group, and also make
# qpidd's primary group == ais.
usermod -g ais -G root qpidd
%else
# [RHEL-6, Fedora] corosync: Set up corosync permissions for user qpidd
cat > /etc/corosync/uidgid.d/qpidd <<EOF
uidgid {
        uid: qpidd
        gid: qpidd
}
EOF
%endif
/sbin/ldconfig

%postun -n %{base_name}-server-cluster
/sbin/ldconfig

%endif # with_cluster

# === Package: qpid-cpp-server-store ===

%package -n %{base_name}-server-store
Summary: Red Hat persistence extension to the Qpid messaging system
Group: System Environment/Libraries
License: LGPL 2.1+
Requires: %{base_name}-server = %{version}-%{release}
Requires: %{base_name}-client = %{version}-%{release}
Requires: db4
Requires: libaio
Obsoletes: rhm

%description -n %{base_name}-server-store
Red Hat persistence extension to the Qpid AMQP broker: persistent message
storage using a libaio-based asynchronous journal. (Built from store svn
r.%{store_svnrev} plus the patches from the 0.18 store branch.)

%files -n %{base_name}-server-store
%defattr(-,root,root,-)
%doc ../store-%{store_version}/README 
%_libdir/qpid/daemon/msgstore.so*
%{python_sitearch}/qpidstore/__init__.py*
%{python_sitearch}/qpidstore/jerr.py*
%{python_sitearch}/qpidstore/jrnl.py*
%{python_sitearch}/qpidstore/janal.py*
%_libexecdir/qpid/resize
%_libexecdir/qpid/store_chk
%attr(0775,qpidd,qpidd) %dir %_localstatedir/rhm

%post -n %{base_name}-server-store
/sbin/ldconfig

%postun -n %{base_name}-server-store
/sbin/ldconfig

# === Package: rh-qpid-cpp-tests (internal package, not distributed) ===

%package -n rh-%{base_name}-tests
Summary: Internal Red Hat test utilities
Group: System Environment/Tools
Requires: %{base_name}-server = %{version}-%{release}
Requires: %{base_name}-client = %{version}-%{release}
Obsoletes: rh-qpidc-tests

%description -n rh-%{base_name}-tests
Tools which can be used by Red Hat for doing different tests
in RHTS and other places and which customers do not need
to receive at all.

%files -n rh-%{base_name}-tests
%defattr(755,root,root,-)
/opt/rh-qpid/failover/run_failover_soak
/opt/rh-qpid/failover/failover_soak
/opt/rh-qpid/clients/declare_queues
/opt/rh-qpid/clients/replaying_sender
/opt/rh-qpid/clients/resuming_receiver
/opt/rh-qpid/clients/receiver
/opt/rh-qpid/clients/sender
/opt/rh-qpid/clients/qpid-receive
/opt/rh-qpid/clients/qpid-send

# ===

%prep
# Sanity checks on flag settings
%if %{fedora} && %{rhel_5}
echo "ERROR: Both {fedora} and {rhel_5} are true (1) at the same time."
exit 1
%endif

%setup -q -n qpid-%{version}
%setup -q -T -D -b 1 -n qpid-%{version}

# Qpid patch
%patch0 -p2
%patch7 -p2
%patch3 -p2
%patch4 -p2
%patch6 -p2
%patch8 -p2
%patch9 -p2
%patch10 -p2
%patch11 -p2
%patch12 -p2

# Store patch
pushd ../store-%{version}
%patch2
%patch5
popd

%if %{fedora}
%patch1
%endif

# Doxygen docs
tar -xzf %{SOURCE2} --no-same-owner

%if %{rhel_5}
install -d selinux
install %{SOURCE3} selinux
%endif

%global perftests "qpid-perftest qpid-topic-listener qpid-topic-publisher qpid-latency-test qpid-client-test qpid-txtest"
%global rh_qpid_cpp_tests_failover "failover_soak run_failover_soak"
%global rh_qpid_cpp_tests_clients "replaying_sender resuming_receiver declare_queues sender receiver qpid-send qpid-receive"

# ===
%build
pushd %{_builddir}/qpid-%{version}/cpp
./bootstrap
CXXFLAGS="%{optflags} -DNDEBUG -O3"

# Build everything with all options
%configure --disable-static --with-swig --with-sasl --with-xml --with-ssl --without-help2man \
%if %{with_rdma}
--with-rdma \
%else
--without-rdma \
%endif
%if %{with_cluster}
--with-cpg \
%else
--without-cpg \
%endif
%if %{with_xml}
--with-xml
%else
--without-xml
%endif

make %{LIB_VERSION_MAKE_PARAMS}
popd

# make tools so we have access to qpid-ha script
pushd %{_builddir}/qpid-%{version}/tools
./setup.py build
popd

# Make perftest utilities
pushd %{_builddir}/qpid-%{version}/cpp/src/tests
for ptest in %{perftests}; do
    make $ptest
done
%if !%{fedora}
# Make rh-qpid-cpp-test programs (RH internal)
for rhtest in %{rh_qpid_cpp_tests_failover} %{rh_qpid_cpp_tests_clients}; do
    make $rhtest
done
# Patch run_failover_soak to make it work outside source tree
mv -f run_failover_soak run_failover_soak.orig
cat run_failover_soak.orig | sed -e "s#^src_root=..#src_root=/usr/sbin#" \
                                 -e "s#\$src_root/\.libs#%{_libdir}/qpid/daemon#" \
                                 -e "s#\`dirname \$0\`#../failover#" \
                                 -e "s#^exec #cd /opt/rh-qpid/clients; exec #" > run_failover_soak
%endif
popd

# Store
pushd %{_builddir}/store-%{store_version}
export CXXFLAGS="%{optflags} -DNDEBUG -O3" 
./bootstrap
%configure --disable-static --disable-dependency-tracking --with-qpid-checkout=%{_builddir}/qpid-%{version}

make
popd

# ===

%install
rm -rf %{buildroot}
mkdir -p -m0755 %{buildroot}/%_bindir

pushd %{_builddir}/qpid-%{version}/cpp
make install DESTDIR=%{buildroot}
install -Dp -m0755 etc/qpidd %{buildroot}%{_initrddir}/qpidd
install -Dp -m0755 etc/qpidd-primary %{buildroot}%{_initrddir}/qpidd-primary
install -Dp -m0644 bindings/qpid/qpid.i %{buildroot}%{_includedir}
install -Dp -m0644 bindings/swig_perl_typemaps.i %{buildroot}%{_includedir}
popd

pushd %{_builddir}/qpid-%{version}/tools
./setup.py install --skip-build --root %{buildroot}
popd

# Install perftest utilities
pushd %{_builddir}/qpid-%{version}/cpp/src/tests
for ptest in %{perftests}; do
  libtool --mode=install install -m755 $ptest %{buildroot}/%_bindir
done
%if !%{fedora}
# Install rh-qpid-cpp-test programs (RH internal)
mkdir -p -m 0755 %{buildroot}/opt/rh-qpid/failover
mkdir -p -m 0755 %{buildroot}/opt/rh-qpid/clients
for rhtest in %{rh_qpid_cpp_tests_failover} ; do
    libtool --mode=install install -m 755 $rhtest %{buildroot}/opt/rh-qpid/failover/
done
for rhtest in %{rh_qpid_cpp_tests_clients} ; do
    libtool --mode=install install -m 755 $rhtest %{buildroot}/opt/rh-qpid/clients/
done
%endif # !fedora
popd

#Store
pushd %{_builddir}/store-%{store_version}
make install DESTDIR=%{buildroot}
install -d -m0775 %{buildroot}%{_localstatedir}/rhm
install -d -m0755 %{buildroot}%_libdir/qpid/daemon
popd

# delete everything but qpid-ha from tools
%if "%{python_version}" >= "2.6"
    rm -f %{buildroot}%{python_sitelib}/qpid_tools-*.egg-info
%endif
rm -f %{buildroot}%{python_sitelib}/qpidtoollibs/*
rm -f %{buildroot}%{_bindir}/qpid-cluster
rm -f %{buildroot}%{_bindir}/qpid-cluster-store
rm -f %{buildroot}%{_bindir}/qpid-config
rm -f %{buildroot}%{_bindir}/qpid-printevents
rm -f %{buildroot}%{_bindir}/qpid-queue-stats
rm -f %{buildroot}%{_bindir}/qpid-route
rm -f %{buildroot}%{_bindir}/qpid-stat
rm -f %{buildroot}%{_bindir}/qpid-tool
rm -f %{buildroot}%{_bindir}/qmf-tool

rm -f %{buildroot}%_libdir/qpid/daemon/*.a
rm -f %{buildroot}%_libdir/qpid/daemon/*.la
rm -f %{buildroot}%_libdir/*.a
rm -f %{buildroot}%_libdir/*.la
rm -f %{buildroot}%_sysconfdir/rhmd.conf

rm -f %{buildroot}%_libdir/*.a
rm -f %{buildroot}%_libdir/*.l
rm -f %{buildroot}%_libdir/*.la
rm -f %{buildroot}%_libdir/librdmawrap.so
rm -f %{buildroot}%_libdir/libsslcommon.so
rm -f %{buildroot}%_libdir/qpid/client/*.la
rm -f %{buildroot}%_libdir/qpid/daemon/*.la

# Remove all examples except the messaging dir
# Remove this kludge when the makefile is fixed (ie does not install what is not wanted)!
rm -rf %{buildroot}%_datadir/qpidc/examples/old_api
rm -rf %{buildroot}%_datadir/qpidc/examples/qmf-console
rm -f %{buildroot}%_datadir/qpidc/examples/Makefile
rm -f %{buildroot}%_datadir/qpidc/examples/README.txt

rm -f %{buildroot}%ruby_sitearch/cqmf2.*
rm -f %{buildroot}%ruby_sitearch/cqpid.*
rm -f %{buildroot}%ruby_sitelib/qmf2.rb

rm -f %{buildroot}%python_sitelib/cqmf2.*
rm -f %{buildroot}%python_sitelib/cqpid.*
rm -f %{buildroot}%python_sitelib/qmf2.*
rm -f %{buildroot}%python_sitelib/qmfengine.*
rm -f %{buildroot}%python_sitelib/qmf.*

rm -f %{buildroot}%python_sitearch/_cqmf2.*
rm -f %{buildroot}%python_sitearch/_cqpid.*
rm -f %{buildroot}%python_sitearch/_qmfengine.*

rm -f %{buildroot}%_libdir/libcqpid_perl.so
rm -fr %{buildroot}%_libdir/perl5

rm -f  %{buildroot}%_libdir/_*
rm -fr %{buildroot}%_libdir/qpid/tests
rm -fr %{buildroot}%_libexecdir/qpid/tests
rm -f  %{buildroot}%{ruby_sitearch}/*.la

rm -rf %{buildroot}%_includedir/qmf
rm -rf %{buildroot}%_includedir/qpid/agent
rm -rf %{buildroot}%_includedir/qpid/console
# NOTE: The following line fails on 64-bit as the artifacts are in
# /usr/lib/python2.6/site-packages/ not /usr/lib64/python2.6/site-packages/
# so we do the ugly thing and delete from both places until we can
# work this out!
# TODO: solve this problem
rm -rf %{buildroot}%{python_sitearch}/qmfgen
rm -rf %{buildroot}%{python_sitelib}/qmfgen
# End TODO: solve this problem
rm -f  %{buildroot}%_bindir/qmf-gen
rm -f  %{buildroot}%_libdir/libqmf.so
rm -f  %{buildroot}%_libdir/libqmf2.so
rm -f  %{buildroot}%_libdir/libqmfconsole.so
rm -f  %{buildroot}%_libdir/libqmfengine.so
rm -f  %{buildroot}%_libdir/libqmf.so.*
rm -f  %{buildroot}%_libdir/libqmf2.so.*
rm -f  %{buildroot}%_libdir/libqmfconsole.so.*
rm -f  %{buildroot}%_libdir/libqmfengine.so.*
rm -f  %{buildroot}%{ruby_sitearch}/qmfengine.so
rm -f  %{buildroot}%{ruby_sitelib}/qmf.rb

rm -f  %{buildroot}%_libdir/pkgconfig/qmf2.pc

install -d -m0755 %{buildroot}%{_localstatedir}/lib/qpidd
install -m0600 %{_sourcedir}/qpidd.sasldb %{buildroot}%{_localstatedir}/lib/qpidd
install -d -m0755 %{buildroot}%_libdir/qpidd
install -d -m0755 %{buildroot}/var/run/qpidd

%if %{rhel_5}
install -d %{buildroot}%{_datadir}/selinux/packages
install -m 644 %{_builddir}/qpid-%{version}/selinux/qpidd.pp %{buildroot}%{_datadir}/selinux/packages
%endif

# enable auth by default
echo "auth=yes" >> %{buildroot}/etc/qpidd.conf

rm -f  %{buildroot}%_mandir/man1/*
cp %{SOURCE4} %{buildroot}%_mandir/man1
# ===

%clean
rm -rf %{buildroot}

# ===

%check
# All tests currently disabled, using 'make check' takes too long.
# TODO: Find a small smoke test that runs quickly, perhaps a special make target?

#pushd %{_builddir}/qpid-%{version}/cpp
# LANG=C needs to be in the environment to deal with a libtool issue
# temporarily disabling make check due to libtool issues
# needs to be re-enabled asap
#LANG=C ECHO=echo make check
#popd

# Store
#pushd %{_builddir}/store-%{store_version}
#make check
#popd

# ===

%post
/sbin/ldconfig

# ===

%postun
/sbin/ldconfig

# ===

%changelog
* Fri Jun 26 2015 Mike Cressman <mcressma@redhat.com> - 0.18-39
- BZ 1219554 - segfault when processing QMF method during periodic processing
- BZ 1223730 - rerouting messages from priority queue reverses priority ordering

* Mon Feb 9 2015 Mike Cressman <mcressma@redhat.com> - 0.18-38
- BZ 1189391 - anonymous access to qpidd cannot be prevented
- BZ 1189392 - qpidd can be crashed by unauthenticated user
- BZ 1142833 - purge expired messages on separate worker thread

* Thu Oct 30 2014 Mike Cressman <mcressma@redhat.com> - 0.18-36
- BZ 1153763 - disable SSLv3 in cpp client and broker
- BZ 1153775 - disable SSLv3 in windows cpp client

* Thu Oct 9 2014 Mike Cressman <mcressma@redhat.com> - 0.18-35
- remove BZ 1142833 (undo moving purging to a worker thread)

* Tue Sep 30 2014 Mike Cressman <mcressma@redhat.com> - 0.18-33
- BZ 1147968 - Session.nextReceiver() with IMMEDIATE duration does not raise exception when connection is closed

* Fri Sep 19 2014 Mike Cressman <mcressma@redhat.com> - 0.18-32
- BZ 1142866 - Purging TTL expired messages takes longer than before
- BZ 1142833 - Purging TTL expired messages blocks all other timers, causing connection drops

* Tue Sep 9 2014 Mike Cressman <mcressma@redhat.com> - 0.18-31
- BZ 1136294 - memory leak when purging priority ring queue
- BZ 1132395 - memory leak when using federation with unreliable link

* Tue Aug 19 2014 Mike Cressman <mcressma@redhat.com> - 0.18-29
- BZ 1128654 - nextReceiver with IMMEDIATE duration always returns null
- BZ 1121615 - message to ring queue with prio>9 causes segfault
- BZ  860691 - fix performance for large priority ring queue

* Tue Jun 17 2014 Mike Cressman <mcressma@redhat.com> - 0.18-25
- BZ 1103094 - fix backport for deadlock and memory leak bug

* Fri Jun 6 2014 Mike Cressman <mcressma@redhat.com> - 0.18-24
- BZ 1103094 - fix deadlock and memory leak with auto-delete queue timeout

* Thu May 22 2014 Mike Cressman <mcressma@redhat.com> - 0.18-23
- BZ 1079260 - QMF statistics for LVQs get corrupted
- BZ 1094781 - federated link ends up in connecting state forever after connecting while broker is shutting down

* Fri Jan 17 2014 Mike Cressman <mcressman@redhat.com> - 0.18-20
- BZ  966004 - use correct exception object for older ssl implementations
- BZ 1030406 - segfault in Queue::isExpired() when debug logging for queue is enabled
- BZ 1030608 - qpid segfaults in qpid::ha::BrokerReplicator::disconnected
- BZ 1030637 - cluster restart with cluster-size=3, auth=yes
- BZ 1036650 - ensure that replaced LVQ messages are deleted from store
- BZ 1041575 - don't delete subscription queue when closing link if it was explicitly declared non-exclusive
- BZ 1042224 - durable LVQ raises journal error when only transient messages are sent
- BZ 1044002 - setting heartbeat has no effect on connection establishment timeout

* Fri Oct 25 2013 Mike Cressman <mcressman@redhat.com> - 0.18-18
- BZ 966636 - malformed SSL client cert crashes broker
- BZ 990240 - segfault in qpidd if client attempts to transactionally dequeue the same message twice
- BZ 990542 - cluster restart stalled with cluster-size=2 and auth=yes
- BZ 1005699 - store module does not raise exception when attempting to enqueue a message bigger than the journal size
- BZ 1007398 - Dequeue rid is not enqueued on LVQ 

* Wed Jun 19 2013 Mike Cressman <mcressman@redhat.com> - 0.18-17
- BZ 964189 - improved the counting for replication shutoff
- BZ 971295 - change name of replication shutoff switch
- BZ 948489 - get replication shutoff working correctly w/cluster

* Mon Jun 3 2013 Mike Cressman <mcressman@redhat.com> - 0.18-16
- BZ 951296 - removed new --credit switch, instead set federation
  credit unlimited to avoid qmf schema change in MRG 2.3

* Wed May 15 2013 Mike Cressman <mcressman@redhat.com> - 0.18-15
- Errata build 1
- BZs: 847038,861162,868951,923452,948489,951719,951296,953777
       956240,957869,958895,961444
- HA BZs: 955718,955752

* Thu Jan 24 2013 Mike Cressman <mcressman@redhat.com> - 0.18-14
- consolidated the store patch files, now using the new 0.18 store branch
  (no code changes)
- BZs: 835119,884036,887044,896451
- HA BZs: 883548,886262,886656

* Wed Dec 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-13
- BZs: 846465
- new HA regression BZs: 861162,882149,882373,883548,884036,885658

* Tue Dec 4 2012 Mike Cressman <mcressman@redhat.com> - 0.18-12
- BZs: 872392,872946,877553,878638
- HA BZs: 876688,876720,877081
- added another store patch(5) with updated generated qmf files

* Tue Nov 20 2012 Mike Cressman <mcressman@redhat.com> - 0.18-10
- BZs: 875660, 876664
- HA BZs: 860701, 874192, 874118,874298
- remove faulty fix for 871100
- add new /etc/qpid/qpidd.acl
- qmf build cleanup
- add back deprecated fromString() that we must carry on MRG 2.x
  for compatibility

* Mon Nov 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-9
- BZs: 872172, 873465
- HA BZs: 872696,873883,874118,874298
- fixed windows build

* Tue Nov 6 2012 Mike Cressman <mcressman@redhat.com> - 0.18-7
- BZs: 868881,873347
- HA BZs: 860701 - restore old qmf-1 interfaces, keeping new ones also
- store cleanup related to qmf changes

* Thu Nov 1 2012 Mike Cressman <mcressman@redhat.com> - 0.18-6
- BZs: 868951,871774
- HA BZs: 869002
- revert PACKAGE_NAME naming in generated qmf code

* Wed Oct 31 2012 Mike Cressman <mcressman@redhat.com> - 0.18-4
- BZs: 802656,804752,836141,861838,866677,868403,870058
- HA BZs: 860701,865524,867030,868360,868364,869420,871100
- updated store for new management interfaces
- remove -Wextra compile flag to avoid a boost warning (RHEL-5 only)

* Fri Oct 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-2
- BZs merged from 2.2: 609685,683711,689408,799269,831365
- New BZs: 861165,863349, HA BZs: 859170,860691,860704,865524,865846
- add perl/swig support files to client-devel
- updated man page

* Wed Oct 3 2012 Mike Cressman <mcressman@redhat.com> - 0.18-1
- rebase to 0.18
- update library revs

* Thu Sep 6 2012 Mike Cressman <mcressman@redhat.com> - 0.14-22
- BZs: 609685, 849654, 854004 

* Mon Aug 13 2012 Mike Cressman <mcressman@redhat.com> - 0.14-21
- BZs: 831365, 840982, 844618

* Wed Aug 1 2012 Mike Cressman <mcressman@redhat.com> - 0.14-20
- BZs: 683711, 689408, 825078, 834608, 841196, 841488

* Mon Jul 23 2012 Mike Cressman <mcressman@redhat.com> - 0.14-19
- BZs: 609685, 683711, 693444, 707682, 729311, 801465, 808090,
       809357, 811481, 817283, 826989, 831365, 835628

* Thu Jul 5 2012 Justin Ross <jross@redhat.com> - 0.14-18
- BZs: 609685, 683711, 703563, 707682, 729311, 781560, 799269, 806869,
  806888, 808090, 809357, 811469, 817283

* Thu Apr 26 2012 Justin Ross <jross@redhat.com> - 0.14-17
- Bzs: 781560

* Wed Mar 21 2012 Justin Ross <jross@redhat.com> - 0.14-14
- Rebase to 0.14
- Bzs: 730017, 759114, 760636, 786875, 791249, 795399, 797426, 798236,
  800028, 801310

* Mon Sep 26 2011 Mike Cressman <mcressman@redhat.com> - 0.10-9
- 2.0 errata build
- BZs: 690107,728586,730017,732063,733543,734608,736160

* Mon Jun 9 2011 Mike Cressman <mcressman@redhat.com> - 0.10-8
- 2.0 GA build
- BZs: 709343,711081,671369

* Tue May 17 2011 Mike Cressman <mcressman@redhat.com> - 0.10-7
- 2.0 RC build 3
- BZs: 693895,698721

* Thu May 5 2011 Mike Cressman <mcressman@redhat.com> - 0.10-6
- 2.0 RC build 2
- BZs: 675921,681313,689907,698254,700822,701709,701777,701786,701804

* Thu Apr 28 2011 Ted Ross <tross@redhat.com> - 0.10-5
- Intermediate build to address rpmdiff/multilib problems
- BZs: 689907
- Now sourcing qpidd.sasldb from distcvs
- Now sourcing the doxygen-generated HTML from distcvs

* Wed Apr 20 2011 Mike Cressman <mcressman@redhat.com> - 0.10-4
- 2.0 RC build 1
- BZs: 690261,693407,695263,695716,696637,696655,696698

* Tue Apr 5 2011 Mike Cressman <mcressman@redhat.com> - 0.10-3
- minor update for some upstream 0.10 cleanup

* Wed Mar 23 2011 Mike Cressman <mcressman@redhat.com> - 0.10-1
- Rebase to upstream 0.10 rev 1083082 (store rev remains 4446)
- Removing rev from the package names

* Wed Mar 9 2011 Mike Cressman <mcressman@redhat.com> - 0.9.1079953-1
- Redo latest build because of windows build error, revs 1079953 and 4446

* Tue Mar 8 2011 Mike Cressman <mcressman@redhat.com> - 0.9.1078967-1
- Rebase to revs 1078967 and 4446
- Remove qmf packages (they are being moved elsewhere)

* Mon Feb 23 2011 Mike Cressman <mcressman@redhat.com> - 0.9.1073306-1
- Rebase to revs 1073306 and 4443

* Thu Feb 3 2011 Mike Cressman <mcressman@redhat.com> - 0.7.946106-28
- 1.3.2 RC 2 build 2
- BZs 656385,674183,674338

* Thu Jan 20 2011 Mike Cressman <mcressman@redhat.com> - 0.7.946106-27
- 1.3.2 RC 2 build
- BZs 549670,614944,620742,632188,639994,640312,647719,654872,
- BZs 656385,658936,662765,667735,669343,669452

* Wed Jan 5 2011 Mike Cressman <mcressman@redhat.com> - 0.7.946106-26
- 1.3.2 RC 1 build
- BZs 484691,500430,629892,631969,631973

* Thu Dec 9 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-25
- bugfix build with clustering fixes 
- BZs 629756,648927,655141,655078

* Mon Nov 29 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-24
- second build to produce src rpm for .net RC build
- pulled out 647858 -- it's not supported in 1.3 C++ yet

* Wed Nov 24 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-23
- build to produce src rpm for .net RC build
- BZs 647230,647858,648649,649733

* Tue Nov 16 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-22
- BZ 649822

* Fri Nov 12 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-21
- BZ 652463

* Thu Nov 11 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-20
- BZ 647861 - updates to the previous fix
- rev the library versions (types,broker,messaging)

* Tue Nov 9 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-19
- BZs 620687,621468,631567,647860,647861,649733

* Fri Sep 24 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-17
- Release candidate build 4
- BZ 636827 - store bug can crash the broker

* Wed Sep 22 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-16
- Release candidate build 3
- BZ 636262

* Wed Sep 15 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-15
- Release candidate build 2
- BZ 633681 plus an rpmdiff fix in qmf compilation

* Mon Sep 13 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-14
- Release candidate build 1
- BZs 604688,630996,632349,632395
- added receiver,sender,qpid_receive,qpid_send to rh-qpid-cpp-tests

* Tue Sep 7 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-13
- intermediate test build
- BZs 621527,621571,621715,622699,623805,624714,625450,625541,626341,629035

* Thu Aug 12 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-12
- Beta 5 build 2
- Messaging BZs 620418, 621998, 621666, 622422, 623511
- Store BZs 614943, 620676, 622889, 623653
- updated selinux policy - allow destroy of aixexec_t's 

* Mon Aug 2 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-11
- Beta 5 build 1
- BZs 612535, 616489, 619166, 619765, 620402

* Mon Jul 26 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-10
- BZs 614857, 617281, 617357

* Wed Jul 21 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-9
- intermediate build, including missing windows icon file, plus:
- BZs 614861, 614854, 616072, plus some windows cleanup and a cluster race condition

* Fri Jul 16 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-7
- Beta 4 build 3, including these BZs:
- 572984 588766 608807 609258 609682 609801 609803 610156 610493 610772
- 611543 611847 612615 612682 612988 613216 613753 613912 614054 614344
- add libqpidtypes
- new qpidd.pp selinux policy file (updated)

* Tue Jun 29 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-6
- Beta 4 build 2, including:
- BZ 603085 - VB debug symbols included (.pdb files)
- dotnet API cleanup, more C#, VB, powershell examples

* Mon Jun 28 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-5
- Beta 4 build 1, including:
- BZ 603896 - Message traffic freezes after queues back up
- BZ 604842 - cluster test fails intermittently
- BZ 605763 - Fix cluster broker crashes when management is active
- BZ 606761 - Do not unmask signals while waiting for IO to happen
- BZ 606824 - Acquired but not accepted messages not sent to alternate exchange
- BZ 607550 - Spout was ignoring frame while closing connection
- BZ 607552 - ttl is lost for federation routes where trace id is added
- BZ 607748 - Crash on exit in store cluster tests.
- BZ 608118 - New messaging API lacks access to some 0-10 headers

* Fri Jun 18 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-4
- Beta 3 build 2, including:
- new shared library revision numbering mechanism applied
- BZ 602198 - qpidd crashes when testing heartbeats
- BZ 603805 - .NET bindings for the C++ Messaging API
- BZ 603835 - Clean up connections causing extra connection objects in the management agent map
- BZ 603839 - Concurrent tagging of message with trace id while message is delivered from another queue causes segfault
- BZ 604152 - Do not default to auth=no in the default qpidd.conf file

* Mon Jun 14 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-3
- Beta 3 build 1, including:
- BZ 508959 - Attempt to propagate binding info over dynamic link can crash broker if session has already failed
- BZ 538188 - connection.start() hangs if connection is not accepted
- BZ 566691 - Abort in qpid::management::ManagementAgent::periodicProcessing on shutting down qpidd
- BZ 577274 - windows-related work, including updating the examples
- BZ 577362 - Long failover_soak test hangs.
- BZ 582460 - Remove dependency on qpid::sys::AbsTime
- BZ 589675 - Fix initialization-order problem with URL protocol tags
- BZ 589683 - Broker misconfiguration causes broker stop to fail
- BZ 591139 - RDMA fixes
- BZ 591292 - Fix for heartbeat related segfault
- BZ 591650 - Ensure close is called for a disconnect, preventing leaks
- BZ 596765 - Remove global shared_ptr to store in store plugin
- BZ 596907 - Fixed Default behaviour of new messaging client is to retry forever
- BZ 597066 - Python Connection object should use None as default username, not guest
- BZ 597149 - qpid python high level API clients not runnable on RHEL4
- BZ 597362 - Sporadic failure of check-long in cluster_tests.py test_failover.
- BZ 598350 - Fixed compilation error on windows
- BZ 598516 - Fixed sporadic client "reserved bits not 0" exceptions with cluster + encryption.
- BZ 598550 - Alleviates some of the broker load for QMF V2 format requests
- BZ 598557 - qpidd --no-data-dir with store loaded segfaults
- BZ 598597 - fix client leaks on linux
- BZ 598948 - qpid c++ client occasionly fails to authenticate using GSSAPI
- BZ 599470 - options string for connection does not work for some types
- BZ 599700 - Console examples sometimes fail due to not waiting for the broker connection to complete
- BZ 601277 - qpidd broker crash
- BZ 601828 - QMF Agent returning STATUS_USER returns error 7 to QMF Console
- BZ 602347 - Fix cluster-safe assertion in connection negotiation.
- BZ 602672 - Message::getSubject() returns an empty string even if the message has a subject

* Fri May 28 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-2
- Second beta 2 build - first respin
- BZ 558526 - clustered qpidd shutdowns during start-up
- BZ 569698 - sasl_decode buffer overflow under load
- BZ 577353 - Executables in $PATH have bad names
- BZ 586544 - qpid::agent::ManagementAgent::init call doesn't provide complete connection control
- BZ 587182 - clustered broker reports 'ObjectId collision in moveNewObjects'
- BZ 587190 - qpid c++ (perftest) clients hang
- BZ 591420 - C++ clients on windows hang at program end
- BZ 592999 - clustered persistent broker leaves cluster with error when cluster nodes started from clean store
- BZ 593828 - QMF: python console needs ability to filter unsolicited events
- BZ 593831 - QMF: c++ console needs ability to filter unsolicited events
- BZ 594761 - qpidd segfaults under high load
- BZ 595438 - qpidd+msgstore crashes in mrg::msgstore::InactivityFireEvent::~InactivityFireEvent() -> free()
- BZ 596765- Shutdown order in broker causes invalid writes by ManagementObject in store

* Wed May 19 2010 Mike Cressman <mcressman@redhat.com> - 0.7.946106-1
- Rebase to latest trunk revisions (946106,3975) - pre-beta 2 build (not final)
- add libqpidmessaging and new api examples

* Thu Apr 29 2010 Mike Cressman <mcressman@redhat.com> - 0.7.935473-1
- Rebase to latest trunk revisions (939184,3943) - beta 1+ build
- Add two new python scripts to qpid-cpp-server-store deliverables

* Mon Apr 19 2010 Mike Cressman <mcressman@redhat.com> - 0.7.935473-1
- Rebase to latest trunk revisions (935473,3913) - beta 1 build
- require selinux-policy-base

* Wed Mar 31 2010 Mike Cressman <mcressman@redhat.com> - 0.7.929717-1
- Rebase to latest trunk revisions (929717,3889) - alpha 3 build

* Wed Mar 3 2010 Mike Cressman <mcressman@redhat.com> - 0.7.916826-2
- Add back missing rh-qpid-tests (internal) package and qpid-boost

* Mon Mar 1 2010 Mike Cressman <mcressman@redhat.com> - 0.7.916826-1
- Rebase to revs 916826 and 3860
- Merge RHEL-4 specifics into spec file from RHEL-5 (new package names)

* Tue Feb 16 2010 Justin Ross <jross@redhat.com> - 0.7.909548-1
- Rebase qpid to 909548

* Wed Feb 10 2010 Mike Cressman <mcressman@redhat.com> - 0.7.908272-1
- Rebase to latest trunk revisions (908272,3847)

* Thu Feb 4 2010 Mike Cressman <mcressman@redhat.com> - 0.7.904602-4
- Fix typo with e2fsprogs-devel install dependency

* Wed Feb 3 2010 Mike Cressman <mcressman@redhat.com> - 0.7.904602-3
- Merged in RHEL-6 spec file changes

* Wed Feb 3 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-5
- Related: rhbz#554415
  Changed name of fedora_lib_patch flag to simply fedora
  Added rhel_5 flag, and put in switches for rhel-5 libs
  Added new boost libs for RHEL-6/Fedora

* Tue Jan 26 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-3
- Fixed some rpmlint warnings.

* Fri Jan 22 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-2
- Rebuild because of glitch in brew handling new tags.

* Thu Jan 21 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-1
- Corrected naming of rpms by adding pkg_name variable.

* Thu Jan 21 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-1
- First build of qpid non-core components (ie which are part of the MRG
  channel), this build is based on the RHEL-6 spec file.

* Tue Oct 27 2009 Nuno Santos <nsantos@redhat.com> - 0.5.819819-2
- Renaming of subpackages as per http://fedoraproject.org/wiki/Features/ImprovedQpidCppPackaging

* Tue Sep 29 2009 Nuno Santos <nsantos@redhat.com> - 0.5.819819-1
- Rebased to svn rev 819819 for F12 beta

* Thu Sep 24 2009 Nuno Santos <nsantos@redhat.com> - 0.5.818599-1
- Rebased to svn rev 818599
- rhm-cpp-server-store obsoletes rhm top-level package

* Fri Sep 19 2009 Nuno Santos <nsantos@redhat.com> - 0.5.817349
- Rebased to svn rev 817349

* Wed Jul 29 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 0.5.790661-3
- Update BuildRequires and Requires to use latest stable versions of
  corosync and clusterlib.
- Unbreak perftests define (and fix vim spec syntax coloring).

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.790661-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jul  2 2009 Nuno Santos <nsantos@redhat.com> - 0.5.790661-1
- Rebased to svn rev 790661; .so lib numbers bumped

* Fri Jun 26 2009 Nuno Santos <nsantos@redhat.com> - 0.5.788782-1
- Rebased to svn rev 788782

* Mon Jun 22 2009 Nuno Santos <nsantos@redhat.com> - 0.5.787286-1
- Rebased to svn rev 787286

* Wed Jun 10 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 0.5.752600-8
- update BuildRequires to use corosynclib-devel in correct version.
- update BuildRequires to use clusterlib-devel instead of the obsoleted
  cmanlib-devel.
- drop Requires on cmanlib. This should come in automatically as part
  of the rpm build process.
- re-align package version to -8. -7 didn't have a changelog entry?
- add patch to port Cluster/Cpg to newest Cpg code.
- change patch tag to use patch0.

* Mon May  4 2009 Nuno Santos <nsantos@redhat.com> - 0.5.752600-5
- patch for SASL credentials refresh

* Wed Apr  1 2009 Michael Schwendt <mschwendt@fedoraproject.org> - 0.5.752600-5
- Fix unowned examples directory in -devel pkg.

* Mon Mar 16 2009 Nuno Santos <nsantos@localhost.localdomain> - 0.5.752600-4
- BZ483925 - split docs into a separate noarch subpackage

* Mon Mar 16 2009 Nuno Santos <nsantos@redhat.com> - 0.5.752600-3
- Disable auth by default; fix selinux requires

* Wed Mar 11 2009 Nuno Santos <nsantos@redhat.com> - 0.5.752600-1
- Rebased to svn rev 752600

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.738618-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.738618-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jan 28 2009 Nuno Santos <nsantos@redhat.com> - 0.4.738618-2
- Rebased to svn rev 738618

* Tue Jan 20 2009 Nuno Santos <nsantos@redhat.com> - 0.4.734452-3
- BZ474614 and BZ474613 - qpidc/rhm unowned directories

* Thu Jan 15 2009 Nuno Santos <nsantos@redhat.com> - 0.4.734452-1
- Rebased to svn rev 734452

* Tue Dec 23 2008 Nuno Santos <nsantos@redhat.com> - 0.4.728142-1
- Rebased to svn rev 728142
- Re-enable cluster, now using corosync

* Tue Dec  2 2008 Nuno Santos <nsantos@redhat.com> - 0.3.722557-1
- Rebased to svn rev 722557
- Temporarily disabled cluster due to openais version incompatibility

* Wed Nov 26 2008 Nuno Santos <nsantos@redhat.com> - 0.3.720979-1
- Rebased to svn rev 720979

* Fri Nov 21 2008  Mick Goulish <mgoulish@redhat.com>
- updated to 719552

* Thu Nov 20 2008  Mick Goulish <mgoulish@redhat.com>
- updated to 719323
- For subpackage qpidd-cluster, added dependency to cman-devel.
- For subpackage qpidd-cluster, added dependency to qpidc.
- added BuildRequires cman-devel

* Fri Nov 14 2008 Justin Ross <jross@redhat.com> - 0.3.714072-1
- Update to svn rev 714072
- Enable building --with-cpg

* Wed Nov 12 2008 Justin Ross <jross@redhat.com> - 0.3.713378-1
- Update to svn rev 713378

* Fri Nov  7 2008 Justin Ross <jross@redhat.com> - 0.3.712127-1
- Update to svn rev 712127

* Thu Nov  6 2008 Nuno Santos <nsantos@redhat.com> - 0.3.711915-2
- Removed extraneous openais-devel dependency

* Thu Nov  6 2008 Justin Ross <jross@redhat.com> - 0.3.711915-1
- Update to svn rev 711915

* Tue Nov  4 2008 Nuno Santos <nsantos@redhat.com> - 0.3.709187-2
- Remove extraneous dependency

* Thu Oct 30 2008 Nuno Santos <nsantos@redhat.com> - 0.3.709187-1
- Rebsed to svn rev 709187

* Tue Oct 28 2008 Nuno Santos <nsantos@redhat.com> - 0.3.708576-1
- Rebased to svn rev 708576

* Mon Oct 27 2008 Nuno Santos <nsantos@redhat.com> - 0.3.708210-1
- Rebased to svn rev 708210; address make check libtool issue

* Fri Oct 24 2008 Justin Ross <jross@redhat.com> - 0.3.707724-1
- Update to revision 707724

* Thu Oct 23 2008 Justin Ross <jross@redhat.com> - 0.3.707468-1
- Don't use silly idenity defines
- Add new ssl and rdma subpackages
- Move cluster and xml plugins into their own subpackages
- Reflect new naming of plugins

* Wed Aug 21 2008 Justin Ross <jross@redhat.com> - 0.2.687156-1
- Update to source revision 687156 of the qpid.0-10 branch

* Wed Aug 14 2008 Justin Ross <jross@redhat.com> - 0.2.685273-1
- Update to source revision 685273 of the qpid.0-10 branch

* Wed Aug  6 2008 Justin Ross <jross@redhat.com> - 0.2.683301-1
- Update to source revision 683301 of the qpid.0-10 branch

* Thu Jul 15 2008 Justin Ross <jross@redhat.com> - 0.2.676581-1
- Update to source revision 676581 of the qpid.0-10 branch
- Work around home dir creation problem
- Use a license string that rpmlint likes

* Thu Jul 10 2008 Nuno Santos <nsantos@redhat.com> - 0.2.667603-3
- BZ453818: added additional tests to -perftest

* Thu Jun 13 2008 Justin Ross <jross@redhat.com> - 0.2.667603-1
- Update to source revision 667603

* Thu Jun 12 2008 Justin Ross <jross@redhat.com> - 0.2.667253-1
- Update to source revision 667253

* Thu Jun 12 2008 Nuno Santos <nsantos@redhat.com> - 0.2.666138-5
- add missing doc files

* Wed Jun 11 2008 Justin Ross <jross@redhat.com> - 0.2.666138-3
- Added directories for modules and pid files to install script

* Wed May 28 2008 David Sommerseth <dsommers@redhat.com> - 0.2.663761-1
- Added perftest utilities

* Thu May 22 2008 Nuno Santos <nsantos@redhat.com> - 0.2.656926-4
- Additional build flags for i686

* Tue May 20 2008 Nuno Santos <nsantos@redhat.com> - 0.2.656926-3
- BZ 432872: remove examples, which are being packaged separately

* Tue May 20 2008 Justin Ross <jross@redhat.com> -0.2.656926-2
- Drop build requirements for graphviz and help2man

* Wed May 14 2008 Nuno Santos <nsantos@redhat.com> - 0.2-34
- Bumped for Beta 4 release

* Fri May  9 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-33
- Moved qpidd.conf from qpidc package to qpidd package
- Added BuildRequires xqilla-devel and xerces-c-devel to qpidd for XML Exchange
- Added BuildRequires openais-devel to qpidd for CPG
- Added missing Requires xqilla-devel to qpidd-devel

* Thu May  8 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-32
- Added sasl2 config file for qpidd
- Added cyrus-sasl dependencies

* Wed May  7 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-31
- Added python dependency, needed by managementgen

* Wed May  7 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-30
- Added management-types.xml to qpidc-devel package

* Tue May  6 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-29
- Added managementgen to the qpidc-devel package

* Mon Apr 14 2008 Nuno Santos <nsantos@redhat.com> - 0.2-28
 - Fix home dir permissions
 - Bumped for Fedora 9

* Mon Mar 31 2008 Nuno Santos <nsantos@redhat.com> - 0.2-25
- Create user qpidd, start qpidd service as qpidd

* Mon Feb 18 2008 Rafael Schloming <rafaels@redhat.com> - 0.2-24
- Bug fix for TCK issue in Beta 3

* Thu Feb 14 2008 Rafael Schloming <rafaels@redhat.com> - 0.2-23
- Bumped to pull in fixes for Beta 3

* Tue Feb 12 2008 Alan Conway <aconway@redhat.com> - 0.2-22
- Added -g to compile flags for debug symbols.

* Tue Feb 12 2008 Alan Conway <aconway@redhat.com> - 0.2-21
- Create /var/lib/qpidd correctly.

* Mon Feb 11 2008 Rafael Schloming <rafaels@redhat.com> - 0.2-20
- bumped for Beta 3

* Mon Jan 21 2008 Gordon Sim <gsim@redhat.com> - 0.2-18
- bump up rev for recent changes to plugin modules & mgmt

* Thu Jan 03 2008 Nuno Santos <nsantos@redhat.com> - 0.2-17
- add missing header file SessionManager.h

* Thu Jan 03 2008 Nuno Santos <nsantos@redhat.com> - 0.2-16
- limit builds to i386 and x86_64 archs

* Thu Jan 03 2008 Nuno Santos <nsantos@redhat.com> - 0.2-15
- add ruby as a build dependency

* Tue Dec 18 2007 Nuno Santos <nsantos@redhat.com> - 0.2-14
- include fixes from Gordon Sim (fragmentation, lazy-loading, staging) 
  and Alan Conway (exception handling in the client).

* Thu Dec 6 2007 Alan Conway <aconway@redhat.com> - 0.2-13
- installcheck target to build examples in installation.

* Thu Nov 8 2007 Alan Conway <aconway@redhat.com> - 0.2-10
- added examples to RPM package.

* Thu Oct 9 2007 Alan Conway <aconway@redhat.com> - 0.2-9
- added config(noreplace) for qpidd.conf

* Thu Oct 4 2007 Alan Conway <aconway@redhat.com> - 0.2-8
- Added qpidd.conf configuration file.
- Updated man page to detail configuration options.

* Thu Sep 20 2007 Alan Conway <aconway@redhat.com> - 0.2-7
- Removed apr dependency.

* Wed Aug 1 2007 Alan Conway <aconway@redhat.com> - 0.2-6
- added --disable-cluster flag

* Tue Apr 17 2007 Alan Conway <aconway@redhat.com> - 0.2-5
- Add missing Requires: e2fsprogs-devel for qpidc-devel.

* Tue Apr 17 2007 Alan Conway <aconway@redhat.com> - 0.2-4
- longer broker_start timeout to avoid failures in plague builds.

* Tue Apr 17 2007 Alan Conway <aconway@redhat.com> - 0.2-3
- Add missing Requires: apr in qpidc.

* Mon Apr 16 2007 Alan Conway <aconway@redhat.com> - 0.2-2
- Bugfix for memory errors on x86_64.

* Thu Apr 12 2007 Alan Conway <aconway@redhat.com> - 0.2-1
- Bumped version number for rhm dependencies.

* Wed Apr 11 2007 Alan Conway <aconway@redhat.com> - 0.1-5
- Add qpidd-devel sub-package.

* Mon Feb 19 2007 Jim Meyering <meyering@redhat.com> - 0.1-4
- Address http://bugzilla.redhat.com/220630:
- Remove redundant "cppunit" build-requires.
- Add --disable-static.

* Thu Jan 25 2007 Alan Conway <aconway@redhat.com> - 0.1-3
- Applied Jim Meyerings fixes from http://mail-archives.apache.org/mod_mbox/incubator-qpid-dev/200701.mbox/<87hcugzmyp.fsf@rho.meyering.net>

* Mon Dec 22 2006 Alan Conway <aconway@redhat.com> - 0.1-1
- Fixed all rpmlint complaints (with help from David Lutterkort)
- Added qpidd --daemon behaviour, fix init.rc scripts

* Fri Dec  8 2006 David Lutterkort <dlutter@redhat.com> - 0.1-1
- Initial version based on Jim Meyering's sketch and discussions with Alan
  Conway
